@@ -4,8 +4,8 @@ from peewee import *
 from peewee import Alias
 from peewee import CompoundSelectQuery
 from peewee import Metadata
-from peewee import SENTINEL
 from peewee import callable_
+from peewee import __deprecated__
 
 
 _clone_set = lambda s: set(s) if s else set()
@@ -234,6 +234,10 @@ class ReconnectMixin(object):
         # mysql-connector raises a slightly different error when an idle
         # connection is terminated by the server. This is equivalent to 2013.
         (OperationalError, 'MySQL Connection not available.'),
+
+        # Postgres error examples:
+        #(OperationalError, 'terminat'),
+        #(InterfaceError, 'connection already closed'),
     )
 
     def __init__(self, *args, **kwargs):
@@ -245,9 +249,11 @@ class ReconnectMixin(object):
             self._reconnect_errors.setdefault(exc_class, [])
             self._reconnect_errors[exc_class].append(err_fragment.lower())
 
-    def execute_sql(self, sql, params=None, commit=SENTINEL):
+    def execute_sql(self, sql, params=None, commit=None):
+        if commit is not None:
+            __deprecated__('"commit" has been deprecated and is a no-op.')
         try:
-            return super(ReconnectMixin, self).execute_sql(sql, params, commit)
+            return super(ReconnectMixin, self).execute_sql(sql, params)
         except Exception as exc:
             # If we are in a transaction, do not reconnect silently as
             # any changes could be lost.
@@ -269,7 +275,7 @@ class ReconnectMixin(object):
                 self.close()
                 self.connect()
 
-            return super(ReconnectMixin, self).execute_sql(sql, params, commit)
+            return super(ReconnectMixin, self).execute_sql(sql, params)
 
 
 def resolve_multimodel_query(query, key='_model_identifier'):
